/*
 * $LastChangedBy$
 * $LastChangedDate$
 * $LastChangedRevision$
 * $HeadURL$
 *
 * Copyright 2014 BlueConic Inc./BlueConic B.V. All rights reserved.
 */
import Foundation
public class PreferredHourListener: BlueConicPlugin {

    private var _client: BlueConicClient!
    private var _context: InteractionContext!

    @objc static let LOG_TAG: String = "PREFERRED_HOUR"
    @objc static let PARAMETER_PROPERTY: String = "property"
    @objc static let PARAMETER_LOCALE: String = "locale"
    @objc static let TAG_PROFILE_PROPERTY: String = "profileproperty"

    /**
     Default initializer for a blueconic plugin
     - parameter client:  An instance of the BlueConicClient
     - parameter context:  An instance of the InteractionContext
     */
    public required convenience init(client: BlueConicClient, context: InteractionContext) {
        self.init()
        self._client = client
        self._context = context
    }

    /**
     OnLoad function for blueconic plugin.
     This starts the plugin.
     */
    public func onLoad() {
        if self._client == nil {
            return
        }

        // get the values from the parameters
        if let property: String = ListenerUtil.getProfilePropertyFromParameters(_context.getParameters()) {
            let locale: String = ListenerUtil.getValueFromParameters(_context, key: PreferredHourListener.PARAMETER_LOCALE)

            let now = Date()
            let myCalendar = Calendar.current
            let comps = myCalendar.dateComponents([.hour], from: now)
            let hours = comps.hour

            let timeFrame: String = getTimeFrame(hours!, locale: locale)
            let days = daysSince2012(now, userCalendar: myCalendar)
            let newChanges: JSON = ["TIME": ListenerUtil.getCurrentTime(), "data": [["p": 1, "d": days, "n": timeFrame]]]
            self._client.addProfileValue("_hl_\(property)", value:newChanges.description)
        }
    }

    private func daysSince2012(_ now: Date, userCalendar: Calendar) -> Int {
        var baseDateComponents = DateComponents()
        baseDateComponents.year = 2012
        baseDateComponents.month = 1
        baseDateComponents.day = 1
        (baseDateComponents as NSDateComponents).timeZone = TimeZone(identifier: "UTC")
        let base: Date = userCalendar.date(from: baseDateComponents)!
        return Int(floor((Date().timeIntervalSince(base) as Double) / (24 * 3600)))
    }

    /**
     Returns the hour timestamp, eg 09:00 - 10:00 for NL and 9 AM - 10 AM for US
     - parameter hour: The hours for the timestamp
     - parameter locale: The locale
     - returns: A readable timestamp based on the locale
     */
    private func getTimeFrame(_ hour: Int, locale: String) -> String {
        return "\(getHour(hour, locale: locale)) - \(getHour(hour + 1, locale:locale))"
    }

    /**
     Returns the timestamp for one hour, eg 09:00 for NL and 9 AM for US
     - parameter hour: The hours
     - parameter locale: The locale
     - returns: A readable hour based on the locale
     */
    private func getHour(_ hour: Int, locale: String) -> String {
        var resultHour = hour
        if "en-us" == locale {
            // use US notation
            let amPm: String = hour >= 12 ? "PM" : "AM"
            resultHour = resultHour % 12
            resultHour = resultHour == 0 ? 12: resultHour // the hour '0' should be '12'

            return "\(resultHour) \(amPm)"
        } else {
            // use NL notation
            let hourString: String = (hour < 10 ? ("0 \(hour)") : "\(hour)")
            return "\(hourString):00"
        }

    }
}
