/*
* $LastChangedBy$
* $LastChangedDate$
* $LastChangedRevision$
* $HeadURL$
*
* Copyright 2014 BlueConic Inc./BlueConic B.V. All rights reserved.
*/

import Foundation

/*
static constants defined here
*/
struct Constants {
    //Default constants: Not labeled to a group or basic variables.
    static let PLIST: String = "plist"
    static let HOST_NAME: String = "bc_server_url"

    static let SHARED: String = "bc_shared"
    static let DEBUG_MODE: String = "bc_debug"
    static let METHOD: String = "method"
    static let RESULT: String = "result"
    static let PROPERTIES: String = "properties"
    static let DOMAINGROUP: String = "domain"
    static let DOMAINGROUPID: String = "domainGroupId"
    static let ID: String = "id"
    static let PARAMS: String = "params"
    static let ID_PREFIX: String = "#"
    static let LOCATION_PREFIX: String = "/"

    static let BLUECONIC_VERSION: String = "2.8.8"
    static let SWIFT_VERSION: String = "5.5"
    static let BLUECONIC_NAME: String = "BlueConic iOS SDK " + BLUECONIC_VERSION
    static let QUEUE_LABEL: String = "com.blueconic.BlueConicClientQueue"
    static let DATE_FORMAT: String = "yyyy-MM-dd HH:mm:ss"

    // Debug
    struct Debug {
        static let CLIENT: String = "BC_CLIENT"
        static let CONNECTOR: String = "BC_CONNECTOR"
        static let INTERACTION_CONTEXT: String = "BC_INTERACTION"
        static let DATA_MANAGER: String = "BC_DATA_MANAGER"
        static let EVENT_MANAGER: String = "BC_EVENT_MANAGER"
        static let LISTENER_UTIL: String = "BC_LISTENER_UTIL"
    }
    struct Flag {
        static let INFO: String = "INFO"
        static let WARN: String = "WARNING"
        static let ERROR: String = "ERROR"
        static let DEBUG: String = "DEBUG"
    }

    //Files constants:
    struct Files {
        // File names
        static let COMMITLOG_NAME: String = "bccommitlog"
        static let REQUEST_COMMITLOG_NAME: String = "bcrequestcommitlog"
        static let CACHE_NAME: String = "cache"
        static let FILE_EXTENSION = ".data"
        // Saved files
        static let COMMITLOG: String = COMMITLOG_NAME + Constants.SWIFT_VERSION + FILE_EXTENSION
        static let REQUEST_COMMITLOG: String = REQUEST_COMMITLOG_NAME + Constants.SWIFT_VERSION + FILE_EXTENSION
        static let CACHE: String = CACHE_NAME + Constants.SWIFT_VERSION + FILE_EXTENSION
        static let ID: String = "id" + FILE_EXTENSION
        static let ENABLED: String = "enabled" + FILE_EXTENSION
        static let BLUECONIC_DIR: String = "blueconic"
        // List of BlueConic file names.
        static let BC_FILE_NAMES: [String] = [COMMITLOG_NAME, REQUEST_COMMITLOG_NAME, CACHE_NAME]

        static let SIMULATOR_USERNAME: String = "bcsimulatorusername" + FILE_EXTENSION
        static let SIMULATOR_MOBILESESSION: String = "bcsimulatormobilesession" + FILE_EXTENSION

    }

    //Rest Calls constants: Eventually we could split it up even more. Like: RestCalls.Profile.getProfile
    struct Calls {
        static let JSON_VALUE: String = "json"
        static let JSON_KEY: String = "alt"

        static let ADD_PROPERTIES: String = "addProperties"
        static let SET_PROPERTIES: String = "setProperties"
        static let GET_PROFILE: String = "getProfile"
        static let GET_PROPERTIES: String = "getProperties"
        static let CREATE_EVENT: String = "createEvent"
    }

    struct ProfileProperties {
        static let ID: String = "profileId"
        static let ZONEID: String = "zoneId"
        static let PARAMETER_KEY: String = "forceCreate"
        static let PARAMETER_VALUE: String = "true"
        
        static let MOBILE_APP_AD_ID: String = "mobile_app_ad_id"
        static let MOBILE_APP_AD_IDS: String = ProfileProperties.MOBILE_APP_AD_ID + "s"
    }

    struct Interactions {
        static let ID: String = "id"
        static let NAME: String = "name"
        static let CLASS: String = "pluginClass"
        static let LOCALE: String = "locale"
        static let DEFAULT_LOCALE: String = "defaultLocale"
        static let TYPE: String = "myInteractionTypeId"
        static let PARAMETER_KEY: String = "type"
        static let PLUGIN_TYPE: String = "myPluginType"
        static let PARAMETER_VALUE: String = "PAGEVIEW"
        static let TIMELINE_CONTEXT_KEY: String = "timelineContext"
        static let INTERACTION_KEY: String = "interaction"
        static let INTERACTIONS_KEY: String = "interactions"
        static let POSITION_KEY: String = "position"
        static let POSITION_NAME: String = "positionName"
        static let PARAMETERS: String = "parameters"
        static let DIALOGUE_ID: String = "dialogueId"
        static let DIALOGUE_NAME: String = "dialogueName"
        
    }

    struct Connections {
        static let ID: String = "id"
        static let PARAMETERS: String = "parameters"
        static let PARAMETER: String = "parameter"
        static let CONNECTIONS_KEY: String = "connections"
    }

    struct Segments {
        static let ID: String = "id"
        static let NAME: String = "name"
        static let SEGMENTS_KEY: String = "segments"
    }
    struct CommitLog {
        static let ENTRIES_KEY: String = "entries"
        static let VALUES_KEY: String = "values"
        static let TYPE_KEY: String = "type"
        static let ID_KEY: String = "identifier"
    }

    struct Event {
        static let TYPE_KEY: String = "eventtype"
        static let ID_KEY: String = "eventidentifier"
        static let COUNT_KEY: String = "eventcount"
        static let PAGEVIEW: String = "PAGEVIEW"
        static let CLICK: String = "CLICK"
        static let VIEW: String = "VIEW"
        static let CONVERSION: String = "CONVERSION"
    }

    struct Connector {
        static let DOMAIN_VALUE: String = "DEFAULT"
        static let USER_AGENT_FIELD: String = "User-Agent"
        static let PROFILE_ID_FIELD: String = "BCSessionID"

        static let CONTENT_TYPE_VALUE: String = "text/plain"
        static let CONTENT_TYPE_FIELD: String = "Content-Type"
        static let ACCEPT_ENCODING_FIELD: String = "Accept-Encoding"
        static let ACCEPT_ENCODING_VALUE: String = "gzip"
        static let REFERRER: String = "referer"
    }

    // Session constants:
    struct Session {
        static let TIMEOUT: Double = 6 * 10 * 1000
        static let LENGTH_KEY: String = "mobile_app_sessionlength"
    }

    //Mobile App constants:
    struct MobileApp {
        static let ID: String = "mobile_app_id"
        static let NAME: String = "mobile_app_name"
        static let NAME_VERSION: String = "mobile_app_nameversion"
        static let OS: String = "mobile_app_os"
        static let OS_VERSION: String = "mobile_app_osversion"
        static let VENDOR: String = "mobile_app_vendor"
        static let MODEL: String = "mobile_app_model"
        static let RESOLUTION: String = "mobile_app_resolution"
        static let PAGEVIEWS: String = "mobile_app_pageviews"

        static let BUNDLE_IDENTIFIER: String = "CFBundleIdentifier"
        static let BUNDLE_NAME: String = "CFBundleDisplayName"
        static let SWIFT_BUNDLE_NAME: String = "CFBundleName"
        static let BUNDLE_VERSION: String = "CFBundleShortVersionString"
    }

}
